#! /usr/bin/python
import os
import sys
from .lib.Helper import Helper
from .lib.Validate import Validate
from .lib.Argument import Argument
from .lib.Where_locate import Where_locate
from .lib.Description import Description
Description=Description()
Argument=Argument(sys.argv)
Validate=Validate(sys.argv)
Helper=Helper()
def main():
    if((Helper.Availale_contents())==True):
        if(len(sys.argv)>1):
            if(Argument.hasCommands(['version'])):
                print("Version :: 2.o")
            if(Argument.hasCommands(['uname'])):
                Validate.uname()
            if(Argument.hasCommands(['pwd'])):
                Validate.pwd()
            if(Argument.hasOption(['--ip']) or Argument.hasCommands(['ip_address'])):
                Validate.ip_address()
            if(Argument.hasOption(['--sv']) or Argument.hasCommands(['sys_version'])):
                Validate.sys_version()
            if(Argument.hasOption(['--dev']) or Argument.hasCommands(['devices'])):
                Validate.devices()
            if(Argument.hasOption(['--n']) or Argument.hasCommands(['numcpu'])):
                Validate.numcpu()
            if(Argument.hasOption(['--l']) or Argument.hasCommands(['load'])):
                Validate.load()
            if(Argument.hasOption(['--c']) or Argument.hasCommands(['cpuinfo'])):
                Validate.cpuinfo()
            if(Argument.hasOption(['--g']) or Argument.hasCommands(['getlogin'])):
                Validate.getlogin()
            if(Argument.hasOption(['--f']) or Argument.hasCommands(['modules'])):
                Validate.modules()
            if(Argument.hasOption(['--m']) or Argument.hasCommands(['meminfo'])):
                Validate.meminfo()
            if(Argument.hasOption(['--w']) or Argument.hasCommands(['bus_details'])):
                Validate.bus_details()
            if(Argument.hasOption(['--v']) or Argument.hasCommands(['disk_usage'])):
                Validate.disk_usage()
            if(Argument.hasOption(['--x']) or Argument.hasCommands(['disk_space'])):
                Validate.disk_space()
            if(Argument.hasOption(['--d']) or Argument.hasCommands(['today_date'])):
                Validate.today_date()
            if(Argument.hasOption(['--t']) or Argument.hasCommands(['date_and_time'])):
                Validate.date_and_time()
            if(Argument.hasOption(['--j']) or Argument.hasCommands(['list_cpu'])):
                Validate.list_cpu()
            if(Argument.hasOption(['--q']) or Argument.hasCommands(['interface'])):
                Validate.interface()
            if(Argument.hasOption(['--k']) or Argument.hasCommands(['list_hardware'])):
                Validate.list_hardware() #TODO : Check the Wheater location is folder or file
            if(Argument.hasOption(['--z']) or Argument.hasCommands(['logged_user'])):
                Validate.logged_user()
            if(Argument.hasOption(['--B']) or Argument.hasCommands(['system_view'])):
                Validate.system_view()
            if(Argument.hasOption(['--C']) or Argument.hasCommands(['download_speed'])):
                Validate.download_speed()
            if(Argument.hasOption(['--E']) or Argument.hasCommands(['upload_speed'])):
                Validate.upload_speed()
            if(Argument.hasOption(['--F']) or Argument.hasCommands(['getuid'])):
                Validate.getuid()
            if(Argument.hasOption(['--G']) or Argument.hasCommands(['getpid'])):
                Validate.getpid()
            if(Argument.hasOption(['--M']) or Argument.hasCommands(['logged_user_on_controlling_Terminal'])):
                Validate.logged_user_on_controlling_Terminal()
            if(Argument.hasOption(['--Q']) or Argument.hasCommands(['ip_address_client'])):
                Validate.ip_address_client()
            if(Argument.hasOption(['--G']) or Argument.hasCommands(['getpid'])):
                Validate.getpid()
            if(Argument.hasOption(['--R']) or Argument.hasCommands(['host_name'])):
                Validate.host_name()
            if(Argument.hasOption(['--U']) or Argument.hasCommands(['ip_Version'])):
                Validate.ip_Version()
            if(Argument.hasCommands(['vmstat'])):
                Validate.vmstat()
            if(Argument.hasCommands(['uptime'])):
                Validate.uptime()
            if(Argument.hasCommands(['htop'])):
                Validate.htop()
            if(Argument.hasCommands(['history'])):
                Validate.history()
            if(Argument.hasCommands(['Desc'])):
                Validate.Desc()
            if(Argument.hasCommands(['bc'])):
                Validate.bc()
            if(Argument.hasCommands(['ls'])):
                Validate.ls()
            if(Argument.hasCommands(['ll'])):
                Validate.ll()
            if(Argument.hasCommands(['ping'])):
                Validate.ping()
            if(Argument.hasCommands(['gzip'])):
                Validate.gzip()
            if(Argument.hasCommands(['mkdir'])):
                Validate.mkdir()
            if(Argument.hasCommands(['free'])):
                Validate.free()
            if(Argument.hasCommands(['top'])):
                Validate.top()
            if(Argument.hasCommands(['head'])):
                Validate.head()
            if(Argument.hasCommands(['w'])):
                Validate.w()
            if(Argument.hasCommands(['echo'])):
                Validate.echo()
            if(Argument.hasCommands(['whoami'])):
                Validate.whoami() 
            if(Argument.hasCommands(['mv'])):
                Validate.mv() 
            if(Argument.hasCommands(['ps'])):
                Validate.ps() 
            if(Argument.hasCommands(['tail'])):
                Validate.tail() 
            if(Argument.hasCommands(['env'])):
                Validate.env()
            if(Argument.hasCommands(['nano'])):
                Validate.nano()
            if(Argument.hasCommands(['vi'])):
                Validate.vi()
            if(Argument.hasCommands(['rm'])):
                Validate.rm()
            if(Argument.hasCommands(['clear'])):
                Validate.clear()
            if(Argument.hasCommands(['su'])):
                Validate.su()
            if(Argument.hasCommands(['wget'])):
                Validate.wget()
            if(Argument.hasCommands(['zip'])):
                Validate.zip()
            if(Argument.hasCommands(['unzip'])):
                Validate.unzip()
            if(Argument.hasCommands(['shutdown'])):
                Validate.shutdown()
            if(Argument.hasCommands(['dir'])):
                Validate.dir()
            if(Argument.hasCommands(['cd'])):
                Validate.cd()
            if(Argument.hasCommands(['reboot'])):
                Validate.reboot()
            if(Argument.hasCommands(['sort'])):
                Validate.sort()
            if(Argument.hasCommands(['tac'])):
                Validate.tac()
            if(Argument.hasCommands(['exit'])):
                Validate.exit()
            if(Argument.hasCommands(['diff'])):
                Validate.diff()
            if(Argument.hasCommands(['dmidecode'])):
                Validate.dmidecode()
            if(Argument.hasCommands(['netstat'])):
                Validate.netstat()
            if(Argument.hasCommands(['mpstat'])):
                Validate.mpstat()
            if(Argument.hasCommands(['wc'])):
                Validate.wc()
            if(Argument.hasCommands(['nproc'])):
                Validate.nproc()
            if(Argument.hasCommands(['sleep'])):
                Validate.sleep()
            if(Argument.hasCommands(['lsblk'])):
                Validate.lsblk()
            if(Argument.hasCommands(['hdparm'])):
                Validate.hdparm()
            if(Argument.hasCommands(['Which_type'])):
                Validate.Which_type()
            if(Argument.hasCommands(['commands'])):
                Validate.commands()
            if((sys.argv[1]=="--help")or(sys.argv[1]=="-h")):
                Helper.Help(sys.argv[0])
        else:
            Helper.Help(sys.argv[0])

            
    else:
        Helper.print_help()


if __name__ == "__main__":
    main()
        



class Argument:
    def __init__(self,args):
        self.args=args
        self.command=[]
        self.option=[]
        self.location=[]
        self.locate=[]
        for arg in self.args:
            if '-' in arg:
                self.option.append(arg)
            elif '--' in arg[:1]:
                self.option.append(arg)
                arg.split('--')
                self.location.append(arg[1])
                print(self.location)
            else:
                self.command.append(arg)

 
    def hasOption(self,options:list): 
        user_options=set(self.option)
        required_option=set(options)
        return list(required_option & user_options)
        
        
    def hasCommands(self,commands:list):
        user_command=set(self.command)
        required_command=set(commands)
        return list(required_command & user_command)
        
    def Validate_loaction(self,option):
        for arg in option:
            if '--' in arg:
                options=arg.split('--')
                self.location.append(options[1])
            else:
                self.locate.append(option)
        
        return self.location
        



        






class Description:
    def Author(self):
        print("Linus Benedict Torvalds Finland Swedish ; born (28 December 1969) is a Finnish software engineer who ")
        print("is the creator and, historically, the lead developer of the Linux kernel, used by Linux distributions ")
        print("and other operating systems such as Android. He also created the distributed version control system Git.\n")
        print("He was honored, along with Shinya Yamanaka, with the 2012 Millennium Technology Prize by the ")
        print("Technology Academy Finland in recognition of his creation of a new open source operating system ")
        print("for computers leading to the widely used Linux kernel.")
        print("He is also the recipient of the 2014 IEEE Computer Society Computer Pioneer Award and the 2018 IEEE Masaru Ibuka Consumer Electronics Award.")
    def History_Linux(self):
        print("The first Linux prototypes were publicly released in late 1991.Version 1.0 was released on 14 March 1994")
        print("Torvalds first encountered the GNU Project in 1991 when another Swedish-speaking computer science student,")
        print("Lars Wirzenius, took him to the University of Technology to listen to free software guru Richard Stallman's speech.")
        print("[citation needed] Torvalds used Stallman's GNU General Public License version 2 (GPLv2) for his Linux kernel.")
        print("After a visit to Transmeta in late 1996,Torvalds accepted a position at the company in California,")
        print("where he worked from February 1997 to June 2003. He then moved to the Open Source Development Labs,")
        print("which has since merged with the Free Standards Group to become the Linux Foundation, under whose auspices he continues to work.")
        print("In June 2004, Torvalds and his family moved to Dunthorpe, Oregon[24] to be closer to the OSDL's headquarters in Beaverton.")
        print("From 1997 to 1999, he was involved in 86open, helping select the standard binary format for Linux and Unix. In 1999, ")
        print("he was named by the MIT Technology Review TR100 as one of the world's top 100 innovators under age 35\n\n")
        print("In 1999, Red Hat and VA Linux, both leading developers of Linux-based software, presented Torvalds with stock options in gratitude for his creation.")
        print("That year both companies went public and Torvalds's share value briefly shot up to about US$20 million.")
        print("His personal mascot is a penguin nicknamed Tux,which has been widely adopted by the Linux community as the Linux kernel's mascot")
        print("Although Torvalds believes 'open source is the only right way to do software', he also has said that he uses the 'best tool for the job', ")
        print("even if that includes proprietary software.He was criticized for his use and alleged advocacy of the proprietary BitKeeper software for version control in the Linux kernel.")
        print("He subsequently wrote a free-software replacement for it called Git.\n\n")
        print("In 2008, Torvalds stated that he used the Fedora Linux distribution because it had fairly good support for the PowerPC processor architecture,")
        print("which he favored at the time.He confirmed this in a 2012 interview.He has also posted updates about his choice of desktop environment,")
        print("often in response to perceived feature regressions\n\n")
        print("The Linux Foundation currently sponsors Torvalds so he can work full-time on improving Linux")
        print("Torvalds is known for vocally disagreeing with other developers on the Linux kernel mailing list.")
        print("Calling himself a 'really unpleasant person', he explained,")
        print("I'd like to be a nice person and curse less and encourage people to grow rather than telling them they are idiots. I'm sorry—I tried, it's just not in me.")
        print("His attitude, which he considers necessary for making his points clear, has drawn criticism from Intel programmer Sage Sharp and systemd developer Lennart Poettering, among others\n\n")
        print("On Sunday, 16 September 2018, the Linux kernel Code of Conflict was suddenly replaced by a new Code of Conduct based on the Contributor Covenant.") 
        print("Shortly thereafter, in the release notes for Linux 4.19-rc4, Torvalds apologized for his behavior,")
        print("calling his personal attacks of the past 'unprofessional and uncalled for' and announced a period of 'time off' to 'get some assistance on how to understand people's emotions and respond appropriately.")
        print("It soon transpired that these events followed The New Yorker approaching Torvalds with a series of questions critical of his conduct.")
        print("Following the release of Linux 4.19 on 22 October 2018, Torvalds returned to maintaining the kernel.")
    def Awards_and_achievements(self):
        print("Year                         Award                                                           Notes")
        print("2018                         IEEE Masaru Ibuka Consumer Electronics Award                    IEEE Masaru Ibuka Consumer Electronics Award is conferred by the Institute of Electrical and Electronics Engineers for outstanding contributions to consumer electronics technology has been named in honor of the co-founder and honorary chairman of Sony Corporation, Masaru Ibuka. 2018 Ibuka award was conferred to Linus Torvalds For his leadership of the development and proliferation of Linux\n\n")
        print("2014                         IEEE Computer Pioneer Award                                     On 23 April 2014, the Institute of Electrical and Electronics Engineers named Torvalds as the 2014 recipient of the IEEE Computer Society's Computer Pioneer Award. The Computer Pioneer Award was established in 1981 by the IEEE Computer Society Board of Governors to recognize and honor the vision of those whose efforts resulted in the creation and continued vitality of the computer industry. The award is presented to outstanding individuals whose main contribution to the concepts and development of the computer field was made at least 15 years earlier\n\n")
        print("2012                         Internet Hall of Fame                                           On 23 April 2012, at Internet Society's Global INET conference in Geneva, Switzerland, Torvalds was one of the inaugural inductees into the Internet Hall of Fame, one of ten in the Innovators category and thirty-three overall inductees\n\n")
        print("2012                         Millennium Technology Prize                                     On 20 April 2012, Torvalds was declared one of two winners of that year's Millennium Technology Prize,[59] along with Shinya Yamanaka.[60] The honor is widely described as technology's equivalent of the Nobel Prize.\n\n")
        print("2010                         C&C Prize                                                       He was awarded the C&C Prize by the NEC Corporation in 2010 for contributions to the advancement of the information technology industry, education, research, and the improvement of our lives\n\n")
        print("2008                         Hall of Fellows                                                 In 2008, he was inducted into the Hall of Fellows of the Computer History Museum in Mountain View, California, for the creation of the Linux kernel and the management of open source development of the widely used Linux operating system.\n\n")
        print("2005                         Vollum Award                                                    In August 2005, Torvalds received the Vollum Award from Reed College.\n\n")
        print("2003                         Linus (Moon)                                                    In 2003, the naming of the asteroid moon Linus was motivated in part by the fact that the discoverer was an enthusiastic Linux user. Although the naming proposal referred to the mythological Linus, son of the muse Calliope and the inventor of melody and rhythm, the name was also meant to honor Linus Torvalds, and Linus van Pelt, a character in the Peanuts comic strip\n\n")
        print("2001                         Takeda Award                                                    In 2001, he shared the Takeda Award for Social/Economic Well-Being with Richard Stallman and Ken Sakamura.\n\n")
        print("2000                         Lovelace Medal                                                  In 2000, he was awarded the Lovelace Medal from the British Computer Society\n\n")
        print("1998                         EFF Pioneer Award                                               In 1998, Torvalds received an EFF Pioneer Award.\n\n")
        print("1997                         Academic Honors                                                 In 1997, Torvalds received his master's degree (Laudatur Grade) from the Department of Computer Science at the University of Helsinki. Two years later he received honorary doctor status at Stockholm University, and in 2000, he received the same honor from his alma mater.University of Helsinki has named an auditorium after Torvalds and his computer is on display at the Department of Computer Science.\n\n")
        print("1996                         9793 Torvalds (Asteroid)                                        In 1996, the asteroid 9793 Torvalds was named after him\n\n")
    def About_Linux(self):
        print("Linux  is a family of open-source Unix-like operating systems based on the Linux kernel,")
        print(" an operating system kernel first released on September 17, 1991, by Linus Torvalds.")
        print(" Linux is typically packaged as a Linux distribution, which includes the kernel and ")
        print("supporting system software and libraries, many of which are provided by the GNU Project.")
        print(" Many Linux distributions use the word 'Linux' in their name, ")
        print("but the Free Software Foundation uses the name 'GNU/Linux' to emphasize the importance of GNU software,")
        print(" causing some controversy.\n")
        print("Popular Linux distributions include Debian, Fedora Linux, and Ubuntu, the latter of which itself consists of")
        print(" many different distributions and modifications, including Lubuntu and Xubuntu. Commercial distributions include Red Hat Enterprise Linux and SUSE Linux Enterprise.")
        print("Desktop Linux distributions include a windowing system such as X11 or Wayland, and a desktop environment such as GNOME or KDE Plasma.")
        print("Distributions intended for servers may omit graphics altogether, or include a solution stack such as LAMP. Because Linux is freely redistributable,")
        print("anyone may create a distribution for any purpose.")
        print("Linux was originally developed for personal computers based on the Intel x86 architecture,")
        print("but has since been ported to more platforms than any other operating system. Because of the dominance of the Linux-based Android on smartphones,")
        print("Linux, including Android, has the largest installed base of all general-purpose operating systems, as of May 2022.")
        print("Although Linux is, as of November 2022, used by only around 2.6 percent of desktop computers,")
        print("the Chromebook, which runs the Linux kernel-based ChromeOS, dominates the US K–12 education market and represents nearly 20 percent of sub-$300 notebook sales in the US.")
        print("Linux is the leading operating system on servers (over 96.4% of the top 1 million web servers' operating systems are Linux),")
        print("leads other big iron systems such as mainframe computers, ")
        print("and is used on all of the world's 500 fastest supercomputers[d] (since November 2017, having gradually displaced all competitors).")
        print("Linux also runs on embedded systems, i.e. devices whose operating system is typically built into the firmware and is highly tailored to the system.")
        print("This includes routers, automation controls, smart home devices, video game consoles,televisions (Samsung and LG Smart TVs),")
        print("automobiles (Tesla, Audi, Mercedes-Benz, Hyundai and Toyota),and spacecraft (Falcon 9 rocket, Dragon crew capsule and the Perseverance rover).")
        print("Linux is one of the most prominent examples of free and open-source software collaboration.")
        print("The source code may be used, modified and distributed commercially or non-commercially by")
        print("anyone under the terms of its respective licenses, such as the GNU General Public License (GPL). The Linux kernel, for example, is licensed under the GPLv2.")
    def Design(self):
        print("Many open source developers agree that the Linux kernel was not designed but rather evolved through") 
        print("natural selection. Torvalds considers that although the design of Unix served as a scaffolding, ")
        print("Linux grew with a lot of mutations – and because the mutations were less than random, they were ")
        print("faster and more directed than alpha-particles in DNA. Eric S. Raymond considers Linux's revolutionary") 
        print("aspects to be social, not technical: before Linux, complex software was designed carefully by small groups,")
        print("Linux evolved in a completely different way. From nearly the beginning, it was rather casually hacked on by ")
        print("huge numbers of volunteers coordinating only through the Internet. Quality was maintained not by rigid ")
        print("standards or autocracy but by the naively simple strategy of releasing every week and getting feedback from") 
        print("hundreds of users within days, creating a sort of rapid Darwinian selection on the mutations introduced by ")
        print("developers.Bryan Cantrill, an engineer of a competing OS, agrees that Linux wasn't designed, it evolved,")
        print("but considers this to be a limitation, proposing that some features, especially those related to security,")
        print(" cannot be evolved into, this is not a biological system at the end of the day, it's a software system.A Linux-based") 
        print("system is a modular Unix-like operating system, deriving much of its basic design from principles established ")
        print("in Unix during the 1970s and 1980s. Such a system uses a monolithic kernel, the Linux kernel, which handles ")
        print("process control, networking, access to the peripherals, and file systems. Device drivers are either integrated") 
        print("directly with the kernel, or added as modules that are loaded while the system is running.")
    def User_interface(self):
        print("The user interface, also known as the shell, is either a command-line interface (CLI), a graphical user interface (GUI), or controls attached to the")
        print(" associated hardware, which is common for embedded systems. For desktop systems, the default user interface is usually graphical, although the CLI is ")
        print("commonly available through terminal emulator windows or on a separate virtual console.")
        print("\n")
        print("CLI shells are text-based user interfaces, which use text for both input and output. The dominant shell used ")
        print("in Linux is the Bourne-Again Shell (bash), originally developed for the GNU project. Most low-level Linux components"), 
        print("including various parts of the userland, use the CLI exclusively. The CLI is particularly suited for automation of ")
        print("repetitive or delayed tasks and provides very simple inter-process communication.")
        print("\n")
        print("On desktop systems, the most popular user interfaces are the GUI shells, packaged together with extensive desktop environments, ")
        print("such as KDE Plasma, GNOME, MATE, Cinnamon, LXDE, Pantheon and Xfce, though a variety of additional user interfaces exist.") 
        print("Most popular user interfaces are based on the X Window System, often simply called 'X'. ")
        print("It provides network transparency and permits a graphical application running on one system to be displayed on") 
        print("another where a user may interact with the application; however, certain extensions of the X ,")
        print("Window System are not capable of working over the network.[79] Several X display servers exist, with the reference implementation, ")
        print("X.Org Server, being the most popular.")
        print("\n")
        print("Server distributions might provide a command-line interface for developers and administrators, but provide a custom interface towards end-users, ")
        print("designed for the use-case of the system. This custom interface is accessed through a client that resides on another system, not necessarily Linux based.")
        print("\n")
        print("Several types of window managers exist for X11, including tiling, dynamic, stacking and compositing. ")
        print("Window managers provide means to control the placement and appearance of individual application windows, and") 
        print("interact with the X Window System. Simpler X window managers such as dwm, ratpoison, i3wm, or") 
        print("herbstluftwm provide a minimalist functionality, while more elaborate window managers such as FVWM, Enlightenment or") 
        print("Window Maker provide more features such as a built-in taskbar and themes, but are still lightweight when compared to desktop environments.") 
        print("Desktop environments include window managers as part of their standard installations, such as Mutter (GNOME), KWin (KDE) or Xfwm (xfce),")
        print(" although users may choose to use a different window manager if preferred.")
        print("\n")
        print("Wayland is a display server protocol intended as a replacement for the X11 protocol; as of 2022, it has received relatively wide adoption.[80] Unlike X11,") 
        print("Wayland does not need an external window manager and compositing manager. Therefore, a Wayland compositor takes the role of the display server,") 
        print("window manager and compositing manager. Weston is the reference implementation of Wayland, while GNOME's Mutter and KDE's KWin are being ported to Wayland as") 
        print("standalone display servers. Enlightenment has already been successfully ported since version 19")
    
    def Naming(self):
        print("Linus Torvalds had wanted to call his invention 'Freax', a portmanteau of 'free', 'freak', and X (as an allusion to Unix). ")
        print("During the start of his work on the system, some of the project's makefiles included the name Freax for about half a year.")
        print("Initially, Torvalds considered the name Linux but dismissed it as too egotistical")
        print("To facilitate development, the files were uploaded to the FTP server  of FUNET in September 1991. ")
        print("Ari Lemmke, Torvalds' coworker at the Helsinki University of Technology (HUT) who was one of the volunteer administrators for the FTP server at the time,")
        print("did not think that 'Freax' was a good name, so he named the project 'Linux' on the server without consulting Torvalds.")
        print("Later, however, Torvalds consented to 'Linux'.")
        print("According to a newsgroup post by Torvalds,the word 'Linux' should be pronounced  with a short 'i' as in 'print' and 'u' as in 'put'. To further demonstrate how the word 'Linux' should be pronounced,")
        print("he included an audio guide  with the kernel source code. However, in this recording,")
        print("he pronounces 'Linux' with a short but close front unrounded vowel.")
    def Development(self):
        print("The primary difference between Linux and many other popular contemporary operating systems is that the Linux kernel and ")
        print("other components are free and open-source software. Linux is not the only such operating system,")
        print(" although it is by far the most widely used.[85] Some free and open-source software licenses are based on the principle of copyleft,") 
        print("a kind of reciprocity: any work derived from a copyleft piece of software must also be copyleft itself.") 
        print("The most common free software license, the GNU General Public License (GPL), is a form of copyleft,") 
        print("and is used for the Linux kernel and many of the components from the GNU Project.")
    def Hardware_support(self):
        print("The Linux kernel is a widely ported operating system kernel, available for devices ranging from mobile phones to supercomputers; ")
        print("it runs on a highly diverse range of computer architectures, including the hand-held ARM-based iPAQ and the IBM mainframes System z9 or System z10.")
        print("Specialized distributions and kernel forks exist for less mainstream architectures; for example, the ELKS kernel fork can run on Intel 8086 or Intel 80286 16-bit microprocessors, ")
        print("while the µClinux kernel fork may run on systems without a memory management unit. ")
        print("The kernel also runs on architectures that were only ever intended to use a manufacturer-created operating system, ")
        print("such as Macintosh computers[101][102] (with both PowerPC and Intel processors), PDAs, video game consoles, portable music players, and mobile phones.")
        print("Linux has a reputation of supporting old hardware very well by maintaining standardized drivers for a long time.")
        print(" There are several industry associations and hardware conferences devoted to maintaining and improving support for diverse hardware under Linux,")
        print(" such as FreedomHEC. Over time, support for different hardware has improved in Linux, resulting in any off-the-shelf purchase having a 'good chance' of being compatible.")
        print("In 2014, a new initiative was launched to automatically collect a database of all tested hardware configurations")
    def Video_input_infrastructure(self):
        print("Linux currently has two modern kernel-userspace APIs for handling video input devices: V4L2 API for video streams and radio, and DVB API for digital TV reception.")
        print("Due to the complexity and diversity of different devices, and due to the large number of formats and standards handled by those APIs, ")
        print("this infrastructure needs to evolve to better fit other devices. Also, a good userspace device library is the key of the success for having")
        print(" userspace applications to be able to work with all formats supported by those devices")
        
        
    def About_Linux_Kernal(self):
        print("The Linux kernel is a free and open-source,[11] monolithic, modular, multitasking, Unix-like operating system kernel. It was originally authored in 1991 by Linus Torvalds for his i386-based PC,")
        print("and it was soon adopted as the kernel for the GNU operating system, which was written to be a free (libre) replacement for Unix.")
        print("Linux is provided under the GNU General Public License version 2 only, but it contains files under other compatible licenses.")
        print("Since the late 1990s, it has been included as part of a large number of operating system distributions, many of which are commonly also called Linux.")
        print("Linux is deployed on a wide variety of computing systems, such as embedded devices, mobile devices (including its use in the Android operating system), personal computers, servers, mainframes, and supercomputers.")
        print("It can be tailored for specific architectures and for several usage scenarios using a family of simple commands (that is, without the need of manually editing its source code before compilation);")
        print("privileged users can also fine-tune kernel parameters at runtime.")
        print("Most of the Linux kernel code is written using the GNU extensions of GCC to the standard C programming language and")
        print("with the use of architecture-specific instructions (ISA) in limited parts of the kernel. ")
        print("This produces a highly optimized executable (vmlinux) with respect to utilization of memory space and task execution times.")
        print("Day-to-day development discussions take place on the Linux kernel mailing list (LKML). Changes are tracked using the version control system git, ")
        print("which was originally authored by Torvalds as a free software replacement for BitKeeper.")
    def Desc_Internal_Command(self):
        print("Internal Commands :")
        print("Commands which are built into the shell. For all the shell built-in commands, execution of the same is fast in the sense that the shell doesn’t have to search the given path for them in the PATH variable,")
        print("and also no process needs to be spawned for executing it.")
        print("Examples: source, cd, fg, etc.")
    def Desc_External_Command(self):
        print("External Commands :")
        print("Commands which aren’t built into the shell. When an external command has to be executed, the shell looks for its path given in the PATH variable,")
        print("and also a new process has to be spawned and the command gets executed. They are usually located in /bin or /usr/bin. ")
        print("For example, when you execute the “cat” command, which usually is at /usr/bin, the executable /usr/bin/cat gets executed.")
        print("Examples: ls, cat etc.")
    def Desc_Included_Command(self):
        print("Included_Command :")
        print("When you create a user command you give it a name (which must be unique and not clash with any of the Opus commands),")
        print("other buttons can then run your user command using its name.")
        print("User commands can also accept parameters (arguments) on the command line, which lets you pass through parameters to external programs or scripts that your user command might invoke.")


class Show_details:
    def tail(self):
        print("Print the last 10 lines of each FILE to standard output.With more than one FILE, precede each with a header giving the file name.")
    def uname(self):
        print("The uname command writes to standard output the name of the operating system that you are using.")
        print("The machine ID number contains 12 characters in the following digit format: xxyyyyyymmss. The xx positions indicate the system and is always 00. The yyyyyy positions contain the unique ID number for the entire system. The mm position represents the model ID. The ss position is the submodel number and is always 00. The model ID describes the ID of the CPU Planar, not the model of the System as a whole.")
        print("Most machines share a common model ID of 4C.")
        print("The machine identifier value returned by the uname command may change when new operating system software levels are installed. This change affects applications using this value to access licensed programs. To view this identifier, enter the uname -m command.")
    def pwd(self):
        print("The pwd command writes to standard output the full path name of your current directory (from the root directory). All directories are separated by a / (slash). The root directory is represented by the first /, and the last directory named is your current directory.")
    def show_ip_address(self):
        print("An IP address is a unique address that identifies a device on the internet or a local network. IP stands for Internet Protocol which is the set of rules governing the format of data sent via the internet or local network.")
        print("In essence, IP addresses are the identifier that allows information to be sent between devices on a network: they contain location information and make devices accessible for communication. The internet needs a way to differentiate between different computers, routers, and websites. IP addresses provide a way of doing so and form an essential part of how the internet works.")
    def sys_version(self):
        print("View Linux System Information. To know only the system name, you can use the uname command without any switch that will print system information or the uname -s command will print the kernel name of your system.")
    def devices(self):
        print("/proc is very special in that it is also a virtual filesystem. It's sometimes referred to as a process information pseudo-file system. It doesn't contain 'real' files but runtime system information (e.g. system memory, devices mounted, hardware configuration, etc). For this reason it can be regarded as a control and information centre for the kernel. In fact, quite a lot of system utilities are simply calls to files in this directory. For example, 'lsmod' is the same as 'cat /proc/modules' while 'lspci' is a synonym for 'cat /proc/pci'. By altering files located in this directory you can even read/change kernel parameters (sysctl) while the system is running.")
    def numcpu(self):  
        print("In this Commands Show's the Number of the CPU's That are present in our system") 
    def load(self):
        print("It will print the System's Current Load Average") 
        print("If you select the Option in -S means.It will Stream Continuously,until you Enter the Control + C COmmand")
    def cpuinfo(self):
        print("Show's The Information about of the CPU present in our System")
    def getlogin(self):
        print("Show's the name of the user logged in on the controlling terminal of the process")
    def modules(self):
        print("In this command Represent the Modules that are Present in our System's")
    def meminfo(self):
        print("Show's The Information about of the Memory in our System")
    def bus_details(self):
        print("Show's The Information about of the Bus's in our System")
    def disk_usage(self):
        print("display file system disk usage.")
    def disk_space(self):
        print("Show's the Disk space")
    def today_date(self):
        print("Show's the Current's Date")
    def date_and_time(self):
        print("Show's the Current Date and Time")
    def list_cpu(self):
        print("Show's The Information about of the list of CPU present in our System")
    def list_hardware(self):
        print("Show's The Information about of the List of Hardware present in our System")
    def interface(self):
        print("Show's The Information about of the Interface present in our System")
    def logged_user(self):
        print("To check information about users who are currently logged into the system, we use the who command in the Linux system. The who command is used to display the users logged into the system")
    def system_view(self):
        print("It's Show's the System Information")
    def htop(self):
        print("Show's the details about Linux environment to determine the cause of load by each process")
    def download_speed(self):
        print("Show's the rate that digital data is transferred from the Internet to your computer")
    def upload_speed(self):
        print("Show's the rate that online data is transferred from your computer to the Internet.")
    def getuid(self):
        print("Show's the current process’s real user id ")
    def getpid(self):
        print("Show's the process ID of the current process.")
    def logged_user_on_controlling_Terminal(self):
        print("Show's the name of the user logged in on the controlling terminal of the process.")
    def ip_address_client(self):
        print("Show's the IP Address client")
    def host_name(self):
        print("Show's the name that is provided to a device to identify it in a local network")
    def history(self):
        print("Show's the history of our Terminal's previously Entered Command")
    def ip_Version(self):
        print("Show's the Internet Protocal Version")
    def uptime(self):
        print("The current time, how long the system has been running, how many users are currently logged on, and the system load averages for the past 1, 5, and 15 minutes")
    def Desc(self):
        print("Show's the Deep Explanation About Author,History_Linux,Awards_and_achievements ,About_Linux,User_interface ,Naming,Development,Hardware_support,Video_input_infrastructure,About_Linux_Kernal ")
    def type_of_commands(self):
        print("Show's the Type's of Command's and Details")
    def bc(self):
        print("It Will open the Calculater")
    def ls(self):
        print("Show's information about the FILEs")
    def ll(self):
        print("Show's information about the FILEs and use a long listing format")
    def ping(self):
        print("If you want to check if your system is connected to router or internet then PING (Packet INternet Groper) is the command for you")
    def mkdir(self):
        print("create a new folder in any directory")
    def gzip(self):
        print("compress any file from")
    def free(self):
        print("check exactly what amount of storage is free and used in physical as well as swap memory in the system")
    def top(self):
        print("monitor all the ongoing processes on the Linux system with the user name, priority level, unique process id and shared memory by each task")
    def echo(self):
        print("Print's the given string or value's") 
    def head(self):
        print("list the first 10 lines of the file you through with head command")
    def w(self):
        print("view's the list of currently logged in users")
    def whoami(self):
        print("which user is logged into system or who you are logged in as")
    def mv(self):
        print("move one file or directory to another file or directory")
    def ps(self):
        print("list of processes that are currently running for your session or for other users on the system")
    def env(self):
        print("used to display all the environment variable in the Linux Terminal window or ")
        print("running another task or program in custom environment without need to make any modifications in current session")
    def nano(self):
        print("Linux command-line text editor just similar to Pico editor which many of you might have used for programming and other purposes")
    def vi(self):
        print("The VI editor is the most popular and classic text editor in the Linux family")
    def rm(self):
        print("remove any file from the working directory")
    def clear(self):
        print("It will clear the Screen")
    def su(self):
        print("Switch to another account right from the Linux Terminal window")
    def wget(self):
        print("Download any file from the internet and best part is download works in background so that you can continue working on your task")
    def zip(self):
        print("To compress one or more files")
    def unzip(self):
        print("To extract files from compressed zip file")
    def shutdown(self):
        print("his command will shutdown the system exactly one minute after being executed.")
    def shutdown_c(self):
        print("You can use shutdown -c command to cancel shutdown.")
    def dir(self):
        print("view the list of all directories and folders present in current working directory")
    def cd(self):
        print("To access particular directory or folder from the file system")
    def reboot(self):
        print("It Will Restart the Entire System")
    def sort(self):
        print("sort file or arrange any record in particular order generally according to their ASCII values.")
    def tac(self):
        print("display the contents of the file in reverse orders")
    def exit(self):
        print("It's used to close the Terminal shell window directly from the command-line")
    def diff(self):
        print("compare the two directories and will display difference between them")
    def dmidecode(self):
        print("retrieve hardware information but if you want information of a particular hardware component")
    def netstat(self):
        print("To monitor incoming and outgoing network connections continuously...")
    def vmstat(self):
        print("Show's the virtual Memory usage")
    def mpstat(self):
        print("display all the information about CPU utilization and performance")
    def wc(self):
        print("Show's the Count the files")
    def nproc(self):
        print("Show's the number of processing units allotted to the currently running process.")
    def sleep(self):
        print("It will delay or pause the execution of command for particular amount of time")
    def lsblk(self):
        print("Show's sysfs filesystem and displays the block device information")
    def Which_type(self):
        print("Find the Given Commend whether internel command or External command's")


class Command_help:
    def tail(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("      Print the last 10 lines of each FILE to standard output.")
        print("Options are:   ")
        print("         tail                        Print the last 10 lines of each FILE to standard output.")
        print("-f                                   output appended data as the file grows")
        print("-h       --help                      display this help and exit")
        print("         show                        print the Description about that Command")

    def uname_help(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("Print certain system information.  With no OPTION, same as -s.")
        print("Options are:   ")
        print("-a,      --all                       print all information, in the following order,")
        print("-s,      kernel-name                 print the kernel name")
        print("-n,      nodename                    print the network node hostname")
        print("-r,      kernel-release              print the kernel release")
        print("-v,      kernel-version              print the kernel version")
        print("-m,      machine                     print the machine hardware name")
        print("-p,      processor                   print the processor type (non-portable)")
        print("-i,      hardware-platform           print the hardware platform (non-portable)")
        print("-o,      operating-system            print the operating system")
        print("-h       --help                      display this help and exit")
        print("         show                        print the Description about that Command")

    def pwd_help(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Print the name of the current working directory.")
        print("Options are:   ")
        print("-L                                    print the value of $PWD if it names the current working directory")
        print("-P                                    print the physical directory, without any symbolic links")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def Desc(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Decription....")
        print("Options are:   ")
        print("        Author                            Show's the details About Linux Author")
        print("        History_Linux                     Show's the History of Linux")
        print("        Awards_and_achievements           Show's the Awards_and_achievements of Linux untill today")
        print("        About_Linux                       Show's the deep details About Linux and It's Details")
        print("        Design                            Show's the Design and Implementation of Linux")
        print("        User_interface                    Show's the User_interface in Linux Operationg System and Linux Terminal's")
        print("        Naming                            Show's the What is the purpose of Linux is  Named in Linux")
        print("        Development                       Show's the Development of Linux and Construction of Linux")
        print("        Hardware_support                  Show's the Hardware_support of Linux and Hardware propertites")
        print("        Video_input_infrastructure        Show's the Video_input_infrastructure of Linux")
        print("        About_Linux_Kernal                Show's about Linux Kernal and It's Flavour's")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")
        
    def ip_address_help(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("Show's the INTERNET PROTOCAL ADDRESS")
        print("Options are:   ")
        print("--ip         ip_address      Show's the Internal Protocal Address")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")
    
    def sys_version(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's  the System version and System's Version Details")
        print("Options are:   ")
        print("--sv         sys_version     View Linux System Information")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")
    
    def devices_help(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Information About Devices")
        print("Options are:   ")
        print("--dev         devices     Show's the Devices THat are included in our System's")
        print("-h            --help      Display this help and exit")
        print("              show        Print the Description about that Command")
    
    def numcpu(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Number of CPU's Present in our Devices")
        print("Options are:   ")
        print("--n          numcpu      Show's the Number of CPU's are Present in our System")
        print("-h           --help      Display this help and exit")
        print("             show        Print the Description about that Command")
    
    def load(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Load average of cureent Devices")
        print("Options are:   ")
        print("--l          load        Show's the Current Load Average of the System")
        print("-h           --help      Display this help and exit")
        print("             show        Print the Description about that Command")

    def cpuinfo(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Information about the CPU's")
        print("Options are:   ")
        print("--c          cpuinfo     Show's the Information about the CPU")
        print("-h           --help      Display this help and exit")
        print("             show        Print the Description about that Command")
    
    def getlogin(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the name of the user logged in on the controlling terminal of the process")
        print("Options are:   ")
        print("--g          getlogin        Show's the name of the user logged in on the controlling terminal of the process")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")

    def modules(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Modules are Present in our System's")
        print("Options are:   ")
        print("--f          modules     Show's the Modules are Present in our System")
        print("-h           --help      Display this help and exit")
        print("             show        Print the Description about that Command")

    def meminfo(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Information about Memory")
        print("Options are:   ")
        print("--m          meminfo     Show's the Information About the Memory Information")
        print("-h           --help      Display this help and exit")
        print("             show        Print the Description about that Command")
    
    def bus_details(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Details about bus_details")
        print("Options are:   ")
        print("--w          bus_details     Show's the Buses are Present in our System")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")

    def disk_usage(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Disk Usage of the Current Directory")
        print("Options are:   ")
        print("--v          disk_usage      Show's the Details About the Disk Usage")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")

    def disk_space(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Disk Space of the Current Directory")
        print("Options are:   ")
        print("--x          disk_space      Show's the Empty Space in the Disk")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")

    def today_date(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Current Date")
        print("Options are:   ")
        print("--d          today_date      Show's the Current's Date")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")

    def date_and_time(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Current Date and Time")
        print("Options are:   ")
        print("--t          date_and_time       Show's the Current Date and Time")
        print("-h           --help              Display this help and exit")
        print("             show                Print the Description about that Command")

    def list_cpu(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the list of CPU Present in our System")
        print("Options are:   ")
        print("--j          list_cpu        Show's the List of the CPU")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")

    def list_hardware(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the list of Hardware's Present in our System")
        print("Options are:   ")
        print("--k         list_hardware        Show's the List of Hardware's ")
        print("-h           --help              Display this help and exit")
        print("             show                Print the Description about that Command")

    def interface(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Information about interface")
        print("Options are:   ")
        print("--q          interface       Show's The Information about of the List of Hardware present in our System")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")

    def logged_user(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Information About users who are currently logged into the system")
        print("Options are:   ")
        print("--z         logged_user       Information about users who are ")
        print("                                     currently logged into the system, we use the who command in the Linux system. The who command ")
        print("                                     is used to display the users logged into the system")
        print("-h           --help            Display this help and exit")
        print("             show              Print the Description about that Command")
    
    def system_view(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the System Information")
        print("Options are:   ")
        print("--B          system_view     It's Show's the System Information")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")

    def htop(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Process That are Running in the System")
        print("Options are:   ")
        print("         htop        Show's the details about Linux environment to determine the cause of load by each process")
        print("-h       --help      Display this help and exit")
        print("         show        Print the Description about that Command")
    
    def download_speed(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the data is transferred from the Internet to your computer")
        print("Options are:   ")
        print("--C          download_speed      Show's the rate that digital data is transferred from the Internet to your computer")
        print("-h           --help              Display this help and exit")
        print("             show                Print the Description about that Command")

    def upload_speed(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Uplaod speed our Computer to the internet")
        print("Options are:   ")
        print("--E          upload_speed        Show's the rate that online data is transferred from your computer to the Internet")
        print("-h           --help               Display this help and exit")
        print("             show                 Print the Description about that Command")

    def getuid(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the real User Information Details")
        print("Options are:   ")
        print("--F          getuid      Show's the current process’s real user id")
        print("-h           --help      Display this help and exit")
        print("             show        Print the Description about that Command")

    def getpid(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Current Process Information Details")
        print("Options are:   ")
        print("--G          getpid      Show's the process ID of the current process")
        print("-h           --help      Display this help and exit")
        print("             show        Print the Description about that Command")

    def logged_user_on_controlling_Terminal(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's Name of the User Logged in on the controlling Terminal")
        print("Options are:   ")
        print("--M          logged_user_on_controlling_Terminal         Show's the name of the user logged in on the controlling terminal of the process")
        print("-h           --help                                      Display this help and exit")
        print("             show                                        Print the Description about that Command")

    def ip_address_client(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the IP Address Client")
        print("Options are:   ")
        print("--Q          ip_address_client       Show's the IP Address client")
        print("-h           --help                  Display this help and exit")
        print("             show                    Print the Description about that Command")

    def host_name(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Host name of The System's")
        print("Options are:   ")
        print("--R          host_name       Show's the name that is provided to a device to identify it in a local network")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")

    def history(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Hostory of the Command line Interface")
        print("Options are:   ")
        print("         history         Show's the history of our Terminal's previously Entered Command ")
        print("-h       --help          Display this help and exit")
        print("         show            Print the Description about that Command")

    def ip_Version(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Type of the Internet Protocal Version")
        print("Options are:   ")
        print("--U          ip_Version      Show's the Internet Protocal Version")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")

    def uptime(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Details About,how long the system has been running")
        print("Options are:   ")
        print("         uptime          The current time, how long the system has been running, how many users are currently logged on, and the system load averages for the past 1, 5, and 15 minutes")
        print("-h       --help          Display this help and exit")
        print("         show            Print the Description about that Command")

    def vmstat(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Detail's about reports various bits of system information")
        print("Options are:   ")
        print("             vmstat           Show's the virtual Memory usage")
        print("-h           --help           Display this help and exit")
        print("             show             Print the Description about that Command")

    def type_of_commands(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Description About the Type of the Command Line tools and Types")
        print("Options are:   ")
        print("-in_c              --In_c_details                Show's the Description About the Internal_Command")
        print("-inc_c             --EX_c_details                Show's the Description About the External_Command")
        print("-ex_c              --Incl_c_details              Show's the Descriptoin About the Included_COmmand")
        print("-h                 --help                        Display this help and exit")
        print("                   show                          Print the Description about that Command")

    def bc(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Simple Calculater")
        print("Options are:   ")
        print("             bc              It Will open the Calculater")
        print("-h           --help          Display this help and exit")
        print("             show            Print the Description about that Command")

    def ls(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("          List the Files And Directory's")
        print("Options are: ")
        print("         ls                Show's information about the FILEs")
        print("-h       --help            Display this help and exit")
        print("         show              Print the Description about that Command")
    
    def ll(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's information about the FILEs and use a long listing format")
        print("Options are:   ")
        print("         ll               Show's information about the FILEs and use a long listing format")
        print("-h       --help           Display this help and exit")
        print("         show             Print the Description about that Command")

    def ping(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         check if your system is connected to router")
        print("Options are:   ")
        print("         ping              If you want to check if your system is connected to router or internet then PING (Packet INternet Groper) is the command for you")
        print("-h       --help            Display this help and exit")
        print("         show              Print the Description about that Command")

    def mkdir(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Create the Empty Directory's")
        print("Options are:   ")
        print("         mkdir                 Create the DIrectory in Any Places")
        print("-h       --help                Display this help and exit")
        print("         show                  Print the Description about that Command")

    def gzip(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         compress any file from")
        print("Options are:   ")
        print("         gzip             compress any file from")
        print("-h       --help           Display this help and exit")
        print("         show             Print the Description about that Command")

    def free(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         check exactly what amount of storage is free and used in physical as well as swap memory in the system")
        print("Options are:   ")
        print("         free             check exactly what amount of storage is free and used in physical as well as swap memory in the system")
        print("-h       --help            Display this help and exit")
        print("         show              Print the Description about that Command")

    def top(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         monitor all the ongoing processes on the Linux system with the user name,")
        print("                     priority level, unique process id and shared memory by each task")
        print("Options are:   ")
        print("         top               monitor all the ongoing processes on the Linux system with the user name, priority level, unique process id and shared memory by each task")
        print("-h       --help            Display this help and exit")
        print("         show              Print the Description about that Command")

    def echo(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("Print the Given String or Print The Given Value ")
        print("Options are:   ")
        print("         echo         Print the Given String or Given Value")
        print("-h       --help       Display this help and exit")
        print("         show         Print the Description about that Command")

    def head(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         list the first 10 lines of the file you through with head command")
        print("Options are:   ")
        print("         head                list the first 10 lines of the file you through with head command")
        print("-h       --help              Display this help and exit")
        print("         show                Print the Description about that Command")

    def w(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         view's the list of currently logged in users")
        print("Options are:   ")
        print("         w                  view's the list of currently logged in users")
        print("-h       --help             Display this help and exit")
        print("         show               Print the Description about that Command")

    def whoami(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         which user is logged into system or who you are logged in as")
        print("Options are:   ")
        print("         whoami                      which user is logged into system or who you are logged in as")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def mv(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Move the File or Directory  one place to Another place")
        print("Options are:   ")
        print("         mv                         Move one file or directory to another file or directory")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def ps(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         list of processes that are currently running for your session or for other users on the system")
        print("Options are:   ")
        print("         ps                          list of processes that are currently running for your session or for other users on the system")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def vi(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         One of the Text Editor in Linux ")
        print("Options are:   ")
        print("         vi                          Open the One of the Text Editor in Linux")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")
    
    def nano(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         One of the Text Editor in Linux")
        print("Options are:   ")
        print("         nano                        Open the One of the Text Editor in Linux")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def env(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         display all the environment variable in the Linux Terminal")
        print("Options are:   ")
        print("         env                         Show's the Enviroment Variable Present in our System")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def rm(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Remove the File's or Directory's")
        print("Options are:   ")
        print("         rm                          Remove the File's or Directory's in the Working Directory")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def clear(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Clear the Screen ot Terminal")
        print("Options are:   ")
        print("         clear                       It will Clear the Screen")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def su(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         switch to another account right from the Linux Terminal window")
        print("Options are:   ")
        print("         su                          Switch to another account right from the Linux Terminal window")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def wget(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Download any FIle's from the Internet")
        print("Options are:   ")
        print("         wget                        Download any file from the internet and best part is")
        print("                                                     download works in background so that you can continue working on your task")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def zip(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         To compress one or more files")
        print("Options are:   ")
        print("         zip                         To Compress One or More File's")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def unzip(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         To extract files from compressed zip file")
        print("Options are:   ")
        print("         unzip                       To extract files from compressed zip file")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def shutdown(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Shutdown the System..")
        print("Options are:   ")
        print("         shutdown                   Shutdown the System or lTurn off the System")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")
        
    def shutdown_c(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         To cancel the Executed Shutdown Command")
        print("Options are:   ")
        print("         shutdown_c                  Cancel teh Shutdown Process")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def dir(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         List the Directoy")
        print("Options are:   ")
        print("         dir                         view the list of all directories and folders present in current working directory")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def cd(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Change Directory")
        print("Options are:   ")
        print("         cd                         Change the Directory in the any path")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")
        
    def reboot(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Restart the System")
        print("Options are:   ")
        print("             reboot                Restart the System")
        print("-p                                 Switch off the machine")
        print("-f                                 Force immediate halt/power-off/reboot")
        print("-w                                 Don't halt/power-off/reboot, just write wtmp record")
        print("-d                                 Don't write wtmp record")
        print("-h           --help                Display this help and exit")
        print("             show                  Print the Description about that Command")

    def sort(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         It is used to Sort the Files")
        print("Options are:   ")
        print("         sort                    sort file or arrange any record in particular order generally according to their ASCII values")
        print("-b                               ignore leading blanks")
        print("-d                               consider only blanks and alphanumeric characters")
        print("-f                               fold lower case to upper case characters")
        print("-g                               compare according to general numerical value")
        print("-i                               consider only printable characters")
        print("-m                               compare (unknown) < 'JAN' < ... < 'DEC'")
        print("-h                               compare human readable numbers (e.g., 2K 1G)")
        print("-n                               compare according to string numerical value")
        print("-h       --help                  Display this help and exit")
        print("         show                    Print the Description about that Command")

    def tac(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Display the contents of the file in reverse orders")
        print("Options are:   ")
        print("         tac                 Display the contents of the file in reverse orders")
        print("-h       --help              Display this help and exit")
        print("         show                Print the Description about that Command")

    def exit(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Exit the Terminal or Exit the Current Loggin Account")
        print("Options are:   ")
        print("         exit                        Exit the current state or to exit the Terminal")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def diff(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Difference the Two File's in Line by Line")
        print("Options are:   ")
        print("         diff            compare the two directories and will display difference between them")
        print("-F                       show the most recent line matching RE")
        print("-h       --help          Display this help and exit")
        print("         show            Print the Description about that Command")

    def dmidecode(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         retrieve hardware information but if you want information of a particular hardware component")
        print("Options are:   ")
        print("             dmidecode                  Retrieve hardware information but if you want information of a particular hardware component")
        print("-d           dev-mem FILE               Read memory from device FILE (default: /dev/mem)")
        print("-q           quiet                      Less verbose output")
        print("-s           string KEYWORD             Only display the value of the given DMI string")
        print("-t           type TYPE                  Only display the entries of given type")
        print("-H           handle HANDLE              Only display the entry of given handle")
        print("-u           dump                       Do not decode the entries")
        print("             dump-bin FILE              Dump the DMI data to a binary file")
        print("             from-dump FILE             Read the DMI data from a binary file")
        print("             no-sysfs                   Do not attempt to read DMI data from sysfs files")
        print("-h           --help                     Display this help and exit")
        print("             show                       Print the Description about that Command")

    def netstat(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         To monitor incoming and outgoing network connections continuously")
        print("Options are:   ")
        print("         netstat                     To monitor incoming and outgoing network connections continuously")
        print("-h       --help                      Display this help and exit")
        print("         show                        Print the Description about that Command")

    def mpstat(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         display all the information about CPU utilization and performance")
        print("Options are:   ")
        print("         mpstat           Display all the information about CPU utilization and performance")
        print("-h       --help           Display this help and exit")
        print("         show             Print the Description about that Command")
    
    def wc(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the Count of  the files")
        print("Options are:   ")
        print("         wc              Show's the Count of th e File's")
        print("-h       --help          Display this help and exit")
        print("         show            Print the Description about that Command")

    def nproc(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's the number of processing units allotted to the currently running process")
        print("Options are:   ")
        print("         nproc            Show's the number of processing units allotted to the currently running process")
        print("-h       --help           Display this help and exit")
        print("         show             Print the Description about that Command")

    def sleep(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         It will delay or pause the execution of command for particular amount of time")
        print("Options are:   ")
        print("         sleep            It will delay or pause the execution of command for particular amount of time")
        print("-h       --help           Display this help and exit")
        print("         show             Print the Description about that Command")

    def lsblk(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         Show's sysfs filesystem and displays the block device information")
        print("Options are:   ")
        print("         lsblk                Show's sysfs filesystem and displays the block device information")
        print("-h       --help               Display this help and exit")
        print("         show                 Print the Description about that Command")

    # def hdparm(self,filename):
        # print("Usage: "+filename+" [OPTION] ")
        # print("hdparm           ")
    def Which_type(self,filename):
        print("Usage: "+filename+" [OPTION] ")
        print("         To find the Given Command is Internal Command or External Command or Included Command")
        print("Options are:   ")
        print("         <-->[Argument(cd,ls,cat...)]           To check the Given the Argument is Internal Command's or ")
        print("                                                               External Command's or Included Command's")
        print("-h       --help                                  Display this help and exit")
        print("         show                                    Print the Description about that Command")
        
    
    
    
    
    


import os
import sys
import subprocess
from main.lib.Argument import Argument
Argument=Argument(sys.argv)
class Where_locate:
    def Internal_Command():
        print("This Command Belong's To Internal Command")
    def External_command():
        print("This Command Belong's To External Command")
    def included_command():
        print("This command Belong's Included_command")
    def find_location(self):
        value=Argument.Validate_loaction(sys.argv)
        for i in value:
            if(os.path.exists(f"/usr/bin/{i}") or os.path.exists(f"/usr/sbin/{i}")):
                Where_locate.External_command()
            elif(os.system(f'which {i}')):
                Where_locate.Internal_Command()
            else:
                Where_locate.included_command()
            

        
            


import os
import sys
from main.lib.Argument import Argument
Argument=Argument(sys.argv)
class Helper:
    def Help(self,filename):
        print(f"Usage: {sys.argv[0]} [Options]...")
        print("Options  are :")
        print("verison                                              Show's the Version of the Tool")
        print("uname                                                Show's the Information about Our Machine")
        print("pwd                                                  Show's the Current Print Working Directory")
        print("--ip         ip_address                              Show's the Device Internet Protocal Address")
        print("--sv         sys_version                             Show's  the System version and System's Version Details")
        print("--dev        devices                                 Show's the Information About Devices")
        print("--n          numcpu                                  Show's the Number of CPU's Present in our Devices")
        print("--l          load                                    Show's the Load average of cureent Devices")
        print("--c          cpuinfo                                 Show's the Information about the CPU's")
        print("--g          getlogin                                Show's the name of the user logged in on the controlling terminal of the process ")
        print("--f          modules                                 Show's the Modules are Present in our System's")
        print("--m          meminfo                                 Show's the Information about Memory")
        print("--w          bus_details                             Show's the Details about bus_details")
        print("--v          disk_usage                              Show's the Disk Usage of the Current Directory")
        print("--x          disk_space                              Show's the Disk Space of the Current Directory")
        print("--d          today_date                              Show's the Current Date")
        print("--t          date_and_time                           Show's the Current Date and Time")
        print("--j          list_cpu                                Show's the list of CPU Present in our System")
        print("--k          list_hardware                           Show's the list of Hardware's Present in our System")
        print("--q          interface                               Show's the Information about interface")
        print("--z          logged_user                             Show's the Information About users who are currently logged into the system")
        print("--B          system_view                             Show's the System Information")
        print("             htop                                    Show's the Process That are Running in the System")
        print("--C          download_speed                          Show's the data is transferred from the Internet to your computer")
        print("--E          upload_speed                            Show's the Uplaod speed our Computer to the internet")
        print("--F          getuid                                  Show's the real User Information Details")
        print("--G          getpid                                  Show's the Current Process Information Details")
        print("--M          logged_user_on_controlling_Terminal     Show's Name of the User Logged in on the controlling Terminal")
        print("--Q          ip_address_client                       Show's the IP Address Client")
        print("--R          host_name                               Show's the Host name of The System's")
        print("             history                                 Show's the Hostory of the Command line Interface")
        print("--U          ip_Version                              Show's the Type of the Internet Protocal Version")
        print("             uptime                                  Show's the Details About,how long the system has been running")
        print("             vmstat                                  Show's the Detail's about reports various bits of system information")
        print("             type_of_commands                        Show's the Description About the Type of the Command Line tools and Types")
        print("             Desc                                    Show's the Details about the Histrory,about Linux,About The Linux Kernel and Author")             
        print("             bc                                      It Will open the Calculater")
        print("             ls                                      Show's information about the FILEs")
        print("             ll                                      Show's information about the FILEs and use a long listing format")
        print("             ping                                    check if your system is connected to router or internet then PING ")
        print("                                                                 (Packet INternet Groper) is the command for you")
        print("             mkdir                                   Create the Folder")
        print("             gzip                                    compress any file from")
        print("             free                                    check exactly what amount of storage is free and used in physical as well as swap memory in the system") 
        print("             top                                     monitor all the ongoing processes on the Linux system with the user name, ")
        print("                                                                 priority level, unique process id and shared memory by each task")
        print("             echo                                    Print the Given String or Value's")
        print("             head                                    list the first 10 lines of the file you through with head command")
        print("             w                                       view's the list of currently logged in users")
        print("             mv                                      move one file or directory to another file or directory")
        print("             ps                                      list of processes that are currently running for your session or for other users on the system")
        print("             whoami                                  which user is logged into system or who you are logged in as")
        # print("             tail")            
        print("             env                                     display all the environment variable in the Linux Terminal")
        print("             vi                                      It Will open the One of the Text Editor")
        print("             nano                                    It Will open the One of the Text Editor")  
        print("             rm                                      remove any file from the working directory") 
        print("             clear                                   Clear the Screen")
        print("             su                                      switch to another account right from the Linux Terminal window")
        print("             wget                                    Download any file from the internet and best part is download works")
        print("                                                                      in background so that you can continue working on your task")
        print("             zip                                     To compress one or more files")
        print("             unzip                                   To extract files from compressed zip file")
        print("             shutdown                                Shutfown the System or Currently running process")
        print("             dir                                     view the list of all directories and folders present in current working directory")
        print("             cd                                      Change Directory")
        print("             reboot                                  It Will Restart the Entire System")
        print("             sort                                    It is used to Sort the Files ") 
        print("             tac                                     Display the contents of the file in reverse orders")
        print("             exit                                    It's used to close the Terminal shell window directly from the command-line")
        print("             diff                                    compare the two directories and will display difference between them")
        print("             dmidecode                               retrieve hardware information but if you want information of a particular hardware component")
        print("             netstat                                 To monitor incoming and outgoing network connections continuously")
        print("             mpstat                                  display all the information about CPU utilization and performance")
        print("             wc                                      Show's the Count  of the files")
        print("             nproc                                   Show's the number of processing units allotted to the currently running process.")
        print("             sleep                                   It will delay or pause the execution of command for particular amount of time")
        print("             lsblk                                   Show's sysfs filesystem and displays the block device information")
        print("             Which_type                           Find the given Command to check whether Internal command or External Command or Included COmmands")                               
        print("-h           --help                                  help Option")



    def Availale_contents(self):
        if(Argument.hasCommands(['version'])):
            return True
        if(Argument.hasCommands(['uname'])):
            return True
        if(Argument.hasOption(['--help']) or Argument.hasOption(['-h'])):
            return True
        if(Argument.hasCommands(['pwd'])):
            return True
        if(Argument.hasOption(['--ip']) or Argument.hasCommands(['ip_address'])):
            return True
        if(Argument.hasOption(['--sv']) or Argument.hasCommands(['sys_version'])):
            return True
        if(Argument.hasOption(['--dev']) or Argument.hasCommands(['devices'])):
            return True
        if(Argument.hasOption(['--n']) or Argument.hasCommands(['numcpu'])):
            return True
        if(Argument.hasOption(['--l']) or Argument.hasCommands(['load'])):
            return True
        if(Argument.hasOption(['--c']) or Argument.hasCommands(['cpuinfo'])):
            return True
        if(Argument.hasOption(['--g']) or Argument.hasCommands(['getlogin'])):
            return True
        if(Argument.hasOption(['--f']) or Argument.hasCommands(['modules'])):
            return True
        if(Argument.hasOption(['--m']) or Argument.hasCommands(['meminfo'])):
            return True
        if(Argument.hasOption(['--w']) or Argument.hasCommands(['bus_details'])):
            return True
        if(Argument.hasOption(['--v']) or Argument.hasCommands(['disk_usage'])):
            return True
        if(Argument.hasOption(['--x']) or Argument.hasCommands(['disk_space'])):
            return True
        if(Argument.hasOption(['--d']) or Argument.hasCommands(['today_date'])):
            return True
        if(Argument.hasOption(['--t']) or Argument.hasCommands(['date_and_time'])):
            return True
        if(Argument.hasOption(['--j']) or Argument.hasCommands(['list_cpu'])):
            return True
        if(Argument.hasOption(['--q']) or Argument.hasCommands(['interface'])):
            return True
        if(Argument.hasOption(['--k']) or Argument.hasCommands(['list_hardware'])):
            return True
        if(Argument.hasOption(['--z']) or Argument.hasCommands(['logged_user'])):
            return True
        if(Argument.hasOption(['--B']) or Argument.hasCommands(['system_view'])):
            return True
        if(Argument.hasOption(['--C']) or Argument.hasCommands(['download_speed'])):
            return True
        if(Argument.hasOption(['--E']) or Argument.hasCommands(['upload_speed'])):
            return True
        if(Argument.hasOption(['--F']) or Argument.hasCommands(['getuid'])):
            return True
        if(Argument.hasOption(['--G']) or Argument.hasCommands(['getpid'])):
            return True
        if(Argument.hasOption(['--M']) or Argument.hasCommands(['logged_user_on_controlling_Terminal'])):
            return True
        if(Argument.hasOption(['--Q']) or Argument.hasCommands(['ip_address_client'])):
            return True
        if(Argument.hasOption(['--G']) or Argument.hasCommands(['getpid'])):
            return True
        if(Argument.hasOption(['--R']) or Argument.hasCommands(['host_name'])):
            return True
        if(Argument.hasOption(['--U']) or Argument.hasCommands(['ip_Version'])):
            return True
        if(Argument.hasCommands(['commands'])):
            return True
        if(Argument.hasCommands(['bc'])):
            return True
        if(Argument.hasCommands(['ls'])):
            return True
        if(Argument.hasCommands(['mv'])):
            return True
        if(Argument.hasCommands(['ps'])):
            return True
        if(Argument.hasCommands(['ll'])):
            return True
        if(Argument.hasCommands(['ping'])):
            return True  
        if(Argument.hasCommands(['ps'])):
            return True 
        if(Argument.hasCommands(['mkdir'])):
            return True
        if(Argument.hasCommands(['vmstat'])):
            return True
        if(Argument.hasCommands(['exit'])):
            return True
        if(Argument.hasCommands(['uptime'])):
            return True
        if(Argument.hasCommands(['htop'])):
            return True
        if(Argument.hasCommands(['history'])):
            return True
        if(Argument.hasCommands(['free'])):
            return True
        if(Argument.hasCommands(['top'])):
            return True
        if(Argument.hasCommands(['w'])):
            return True
        if(Argument.hasCommands(['whoami'])):
            return True
        if(Argument.hasCommands(['gzip'])):
            return True
        if(Argument.hasCommands(['Desc'])):
            return True
        if(Argument.hasCommands(['echo'])):
            return True
        if(Argument.hasCommands(['head'])):
            return True
        if(Argument.hasCommands(['env'])):
            return True
        if(Argument.hasCommands(['nano'])):
            return True
        if(Argument.hasCommands(['vi'])):
            return True
        if(Argument.hasCommands(['rm'])):
            return True
        if(Argument.hasCommands(['clear'])):
            return True
        if(Argument.hasCommands(['su'])):
            return True
        if(Argument.hasCommands(['wget'])):
            return True
        if(Argument.hasCommands(['type_of_commands'])):
            return True
        if(Argument.hasCommands(['zip'])):
            return True
        if(Argument.hasCommands(['unzip'])):
            return True
        if(Argument.hasCommands(['shutdown'])):
            return True
        if(Argument.hasCommands(['dir'])):
            return True
        if(Argument.hasCommands(['cd'])):
            return True
        if(Argument.hasCommands(['reboot'])):
            return True
        if(Argument.hasCommands(['sort'])):
            return True
        if(Argument.hasCommands(['tac'])):
            return True
        if(Argument.hasCommands(['diff'])):
            return True
        if(Argument.hasCommands(['dmidecode'])):
            return True
        if(Argument.hasCommands(['netstat'])):
            return True
        if(Argument.hasCommands(['mpstat'])):
            return True
        if(Argument.hasCommands(['wc'])):
            return True
        if(Argument.hasCommands(['nproc'])):
            return True
        if(Argument.hasCommands(['sleep'])):
            return True
        if(Argument.hasCommands(['lsblk'])):
            return True
        if(Argument.hasCommands(['Which_type'])):
            return True
        if(Argument.hasCommands(['tail'])):
            return True
        if(Argument.hasCommands(['commands'])):
            return True
    def print_help(self):
        print("Usage: "+sys.argv[0]+" <command> [Options..]")
        exit(-1)



        


import os
import sys
import platform
import json
from optparse import OptionParser
import psutil
import shutil
from datetime import datetime,date
import readline
from pyspeedtest import * 
import speedtest 
import socket
import ipaddress
import time
from urllib.request import urlopen
import uuid
from main.lib.Description import Description
Description=Description()
from main.lib.Argument import Argument
from main.lib.Command_help import Command_help
from main.lib.Description import Description
Description=Description()
from main.lib.Where_locate import Where_locate
from main.lib.Show_details import Show_details
from main.lib.Helper import Helper
Where_locate=Where_locate()
Helper=Helper()
Argument=Argument(sys.argv)
Show_details=Show_details()
Command_help=Command_help()
url='http://ipinfo.io/json'
hostname = socket.gethostname()
ip_address = socket.gethostbyname(hostname)
class Validate:
    def __init__(self,args):
        self.args=args

    def uname(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['uname'])):
                if(Argument.hasOption(['--all']) or (Argument.hasOption(['-a']))):
                    return os.system("uname -a")
                if(Argument.hasOption(['-s']) or Argument.hasCommands(['kernel-name'])):
                    return os.system("uname -s")
                if(Argument.hasOption(['-n']) or Argument.hasCommands(['nodename'])):
                    return os.system("uname -n")
                if(Argument.hasOption(['-r']) or Argument.hasCommands(['kernel-release'])):
                    return os.system("uname -r")
                if(Argument.hasOption(['-v']) or Argument.hasCommands(['kernel-version'])):
                    return os.system("uname -v")
                if(Argument.hasOption(['-m']) or Argument.hasCommands(['machine'])):
                    return os.system("uname -m")
                if(Argument.hasOption(['-p']) or Argument.hasCommands(['processor'])):
                    return os.system("uname -p")
                if(Argument.hasOption(['-i']) or Argument.hasCommands(['hardware-platform'])):
                    return os.system("uname -i")
                if(Argument.hasOption(['-o']) or Argument.hasCommands(['operating-system'])):
                    return os.system("uname -o")
                elif(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.uname_help(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.uname()
                
        else:
            return Command_help.uname_help(sys.argv[1])
            
    def pwd(self):
            if(Argument.hasCommands(['pwd'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.pwd_help(sys.argv[1])
                if(Argument.hasOption(['-L'])):
                    return os.system("pwd -L")
                if(Argument.hasOption(['-P'])):
                    return os.system("pwd -P")
                if(Argument.hasCommands(["show"])):
                    return Show_details.pwd()
                print(os.getcwd())
    def ip_address(self):
        if(Argument.hasOption(['--ip']) or Argument.hasCommands(['ip_address'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.ip_address_help(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.show_ip_address()
            hostname = socket.gethostname()
            ip_address = socket.gethostbyname(hostname)
            print(ipaddress.ip_address(ip_address))
            # ipaddress.ip_address(ip_address) --> Show's the Internet Protocal Version with Ip Address
            # ipaddress.ip_address('192.0.2.1')
            # Output :: IPv4Address('192.0.2.1')
    def sys_version(self):
        if(Argument.hasOption(['--sv']) or Argument.hasCommands(['sys_version'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.sys_version(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.sys_version()
            return os.system("cat /proc/version")
    def devices(self):
        if(Argument.hasOption(['--dev']) or Argument.hasCommands(['devices'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.devices_help(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.devices()
            return os.system("cat /proc/devices")
    def commands(self):
        if(Argument.hasCommands(['commands'])):
            if(Argument.hasOption(['-in_c']) or Argument.hasOption(['--In_c_details'])):
                return Description.Desc_Internal_Command()
            if(Argument.hasOption(['-inc_c']) or Argument.hasOption(['--Incl_c_details'])):
                return Description.Desc_Included_Command()
            if(Argument.hasOption(['-ex_c']) or Argument.hasOption(['--EX_c_details'])):
                return Description.Desc_External_Command()
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.type_of_commands(sys.argv[1])
    def numcpu(self):
        if(Argument.hasOption(['--n']) or Argument.hasCommands(['numcpu'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.numcpu(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.numcpu()
        print("Number of CPU : ",psutil.cpu_count())
    def load(self):
        if(Argument.hasOption(['--l']) or Argument.hasCommands(['load'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.load(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.load()
            print("Load Average: ", psutil.getloadavg())
    def cpuinfo(self):
        if(Argument.hasOption(['--c']) or Argument.hasCommands(['cpuinfo'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.cpuinfo(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.cpuinfo()
            return os.system("cat /proc/cpuinfo")
    def getlogin(self):
        if(Argument.hasOption(['--g']) or Argument.hasCommands(['getlogin'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.getlogin(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.getlogin()
            return print(os.getlogin())
    def modules(self):
        if(Argument.hasOption(['--f']) or Argument.hasCommands(['modules'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.modules(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.modules()
            return print(os.system("cat /proc/modules"))
    def meminfo(self):
        if(Argument.hasOption(['--m']) or Argument.hasCommands(['meminfo'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.meminfo(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.meminfo()
            return print(os.system("cat /proc/modules"))
    def bus_details(self):
        if(Argument.hasOption(['--w']) or Argument.hasCommands(['bus_details'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.bus_details(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.bus_details()
            return print(os.system("cat /proc/bus"))
    def disk_usage(self):
        if(Argument.hasOption(['--v']) or Argument.hasCommands(['disk_usage'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.disk_usage(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.disk_usage()
            return print(shutil.disk_usage(os.getcwd()))
    def disk_space(self):
        if(Argument.hasOption(['--x']) or Argument.hasCommands(['disk_space'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.disk_space(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.disk_space()
            return os.system("df")
    def today_date(self):
        if(Argument.hasOption(['--d']) or Argument.hasCommands(['today_date'])):
            today = date.today()
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.today_date(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.today_date()
            return print("Today's Date:",date.today())

    def date_and_time(self):
        if(Argument.hasOption(['--t']) or Argument.hasCommands(['date_and_time'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.date_and_time(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.date_and_time()
            today = datetime.now()
            return print("Current date and time is", today)
             
    def list_cpu(self):
        if(Argument.hasOption(['--j']) or Argument.hasCommands(['list_cpu'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.list_cpu(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.list_cpu()
            return print(os.system("lscpu"))
    def list_hardware(self):
        if(Argument.hasOption(['--k']) or Argument.hasCommands(['list_hardware'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.list_hardware(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.list_hardware()
            return (os.system("cat /sys/devices/system/cpu"))
    def interface(self):
        if(Argument.hasOption(['--q']) or Argument.hasCommands(['interface'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.interface(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.interface()
            return os.system("ifconfig -a")
    def logged_user(self):
        if(Argument.hasOption(['--z']) or Argument.hasCommands(['logged_user'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.logged_user(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.logged_user()
            return os.system("last")
    def system_view(self):
        if(Argument.hasOption(['--B']) or Argument.hasCommands(['system_view'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.system_view(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.system_view()
            return os.system("last")
    def htop(self):
        if(Argument.hasCommands(['htop'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.htop(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.htop()
            return os.system("htop")
    def download_speed(self):
        if(Argument.hasOption(['--C']) or Argument.hasCommands(['download_speed'])):
            st = speedtest.Speedtest()
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.download_speed(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.download_speed()
            return print(f"Download speed :: {st.download()}")
    def upload_speed(self):
        if(Argument.hasOption(['--E']) or Argument.hasCommands(['upload_speed'])):
            st = speedtest.Speedtest()
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.upload_speed(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.upload_speed()
            return print(f"Upload Speed :: {st.upload()}")
    def getuid(self):
        if(Argument.hasOption(['--F']) or Argument.hasCommands(['getuid'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.getuid(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.getuid()
            return print("real user ID :: ",os.getuid())
    def getpid(self):
        if(Argument.hasOption(['--G']) or Argument.hasCommands(['getpid'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.getpid(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.getpid()
            return print("current process id :: ",os.getpid())
    def logged_user_on_controlling_Terminal(self):
        if(Argument.hasOption(['--M']) or Argument.hasCommands(['logged_user_on_controlling_Terminal'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.logged_user_on_controlling_Terminal(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.logged_user_on_controlling_Terminal()
            return print("Name of the User Logged in on the controlling Terminal :: ",os.getlogin())
    def ip_address_client(self):
        if(Argument.hasOption(['--Q']) or Argument.hasCommands(['ip_address_client'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.ip_address_client(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.ip_address_client()
            return print(f"IP Address: {ip_address}")
    def host_name(self):
        if(Argument.hasOption(['--R']) or Argument.hasCommands(['host_name'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.host_name(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.host_name()
            return print(f"Hostname: {hostname}")
    def history(self):
        if(Argument.hasCommands(['history'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.history(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.history()
            return os.system("cat /home/sridhard.21cse/.bash_history")
    def ip_Version(self):
        if(Argument.hasOption(['--U']) or Argument.hasCommands(['ip_Version'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.ip_Version(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.ip_Version()
            print("IP Address Version ::")
            hostname = socket.gethostname()
            ip_address = socket.gethostbyname(hostname)
            str(ip_address)
            version=(ipaddress.ip_address(ip_address))  
            # ipaddress.ip_address(ip_address) --> Show's the Internet Protocal Version with Ip Address
            # ipaddress.ip_address('192.0.2.1')
            # Output :: IPv4Address('192.0.2.1')
            return print(version)
    def uptime(self):
        if(Argument.hasCommands(['uptime'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.uptime(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.uptime()
            print("shows system memory, processes, interrupts, paging, block I/O, and CPU info :")
            return print(os.system("vmstat"))
    def vmstat(self):
        if(Argument.hasCommands(['vmstat'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.vmstat(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.vmstat()
            return print(os.system("vmstat"))
    def type_of_commands(self):
        if(Argument.hasCommands(['type_of_commands'])):
            if(Argument.hasCommands(['Internal_Command'])):
                Description.Desc_Internal_Command()
            if(Argument.hasCommands(['External_Command'])):
                Description.Desc_External_Command()
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.type_of_commands(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.type_of_commands()
            return Command_help.type_of_commands(sys.argv[1])

            
    def Desc(self):
        if(Argument.hasCommands(['Desc'])):
            if(Argument.hasCommands(["Author"])):
                return Description.Author()
            if(Argument.hasCommands(["History_Linux"])):
                return Description.History_Linux()
            if(Argument.hasCommands(["Awards_and_achievements"])):
                return Description.Awards_and_achievements()
            if(Argument.hasCommands(["About_Linux"])):
                return Description.About_Linux()
            if(Argument.hasCommands(["Design"])):
                return Description.Design()
            if(Argument.hasCommands(["User_interface"])):
                return Description.User_interface()
            if(Argument.hasCommands(["Naming"])):
                return Description.Naming()
            if(Argument.hasCommands(["Development"])):
                return Description.Development()
            if(Argument.hasCommands(["Hardware_support"])):
                return Description.Hardware_support()
            if(Argument.hasCommands(["Video_input_infrastructure"])):
                return Description.Video_input_infrastructure()
            if(Argument.hasCommands(["About_Linux_Kernal"])):
                return Description.About_Linux_Kernal()
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.Desc(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.Desc()
    def bc(self):
        if(Argument.hasCommands(['bc'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.bc(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.bc()
            return os.system("bc")
    def ls(self):
        if(Argument.hasCommands(['ls'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.ls(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.ls()
            return os.system("ls")
    def ll(self):
        if(Argument.hasCommands(['ll'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.ll(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.ll()
            return os.system("ls -l")
    def ping(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['ping'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.ping(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.ping()
                return os.system(f"ping {sys.argv[2]}")
        else:
            return Command_help.ping(sys.argv[1])
    def mkdir(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['mkdir'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.mkdir(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.mkdir()
                return os.system(f"mkdir {sys.argv[2]}")
        else:
            return Command_help.mkdir(sys.argv[1])
    def gzip(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['gzip'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.gzip(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.gzip()
                return os.system(f"gzip {sys.argv[2]}")
        else:
            return Command_help.gzip(sys.argv[1])
    def free(self):
        if(Argument.hasCommands(['free'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.free(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.free()
            return os.system("free")
    def top(self):
        if(Argument.hasCommands(['top'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.top(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.top()
            return os.system("top")
    def echo(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['echo'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.echo(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.echo()
                return os.system(f"echo {sys.argv[2]}")
        else:
            return Command_help.echo(sys.argv[1])
            
    def head(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['head'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.head(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.head()
                return os.system(f"head {sys.argv[2]}")
        else:
            return Command_help.head(sys.argv[1])

    def mv(self):
        if(len(sys.argv)>3):
            if(Argument.hasCommands(['mv'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.mv(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.mv()
                return os.system(f"mv {sys.argv[2]} {sys.argv[3]}")
        else:
            return Command_help.head(sys.argv[1])

    def w(self):
        if(Argument.hasCommands(['w'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.w(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.w()
            return os.system("w") 

    def ps(self):
        if(Argument.hasCommands(['ps'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.ps(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.ps()
            return os.system("ps -u") 

    def whoami(self):
        if(Argument.hasCommands(['whoami'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.whoami(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.whoami()
            return os.system("whoami")  

    def tail(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['tail'])):
                if(Argument.hasOption(['-f'])):
                    return os.system(f"tail -f {sys.argv[3]}")
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.tail(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.tail()
                return os.system(f"tail -f {sys.argv[2]}") 
            else:
                return Command_help.tail(sys.argv[1])
    def env(self):
        if(Argument.hasCommands(['env'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.env(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.env()
            return os.system("env") 
            

    def vi(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['vi'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.vi(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.vi()
                return os.system(f"vi {sys.argv[2]}")
        else:
            return Command_help.vi(sys.argv[1])

    def nano(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['nano'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.nano(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.nano()
                return os.system(f"nano {sys.argv[2]}")
        else:
            return Command_help.nano(sys.argv[1])

    def rm(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['rm'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.rm(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.rm()
                return os.system(f"rm {sys.argv[2]}")
        else:
            return Command_help.rm(sys.argv[1])

    def clear(self):
        if(Argument.hasCommands(['clear'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.clear(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.clear()
            return os.system("clear")

    def su(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['su'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.su(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.su()
                return os.system(f"su {sys.argv[2]}")
        else:
            return Command_help.su(sys.argv[1])

    def wget(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['wget'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.wget(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.wget()
                return os.system(f"wget {sys.argv[2]}")
        else:
            return Command_help.wget(sys.argv[1])

    def zip(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['zip'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.zip(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.zip()
                return os.system(f"zip {sys.argv[2]}")
        else:
            return Command_help.zip(sys.argv[1])

    def unzip(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['unzip'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.unzip(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.unzip()
                return os.system(f"unzip {sys.argv[2]}")
        else:
            return Command_help.unzip(sys.argv[1])

    def shutdown(self):
        if(Argument.hasCommands(['shutdown'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.shutdown(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.shutdown()
            return os.system("shutdown")
            if(Argument.hasOption(['-c'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.shutdown_c(sys.argv[1])
                return os.system("shutdown -c")

    def dir(self):
        if(Argument.hasCommands(['dir'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.dir(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.dir()
            return os.system("dir")

    def cd(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['cd'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.cd(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.cd()
                return os.system(f"cd {sys.argv[2]}")
        else:
            return Command_help.cd(sys.argv[1])

    def reboot(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['reboot'])):
                if(Argument.hasOption(["-p"])):
                    return os.system("reboot -p")
                if(Argument.hasOption(["-f"])):
                    return os.system("reboot -f")
                if(Argument.hasOption(["-w"])):
                    return os.system("reboot -w")
                if(Argument.hasOption(["-d"])):
                    return os.system("reboot -d")
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.reboot(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.reboot()
        else:
            return Command_help.reboot(sys.argv[1])
            
    def sort(self):
        if((len(sys.argv)>3) or (len(sys.argv)>4)):
            if(Argument.hasCommands(['sort'])):
                if(Argument.hasOption(["-b"])):
                    return os.system("sort -b")
                if(Argument.hasOption(["-d"])):
                    return os.system("sort -d")
                if(Argument.hasOption(["-f"])):
                    return os.system("sort -f")
                if(Argument.hasOption(["-g"])):
                    return os.system("sort -g")
                if(Argument.hasOption(["-i"])):
                    return os.system("sort -i")
                if(Argument.hasOption(["-m"])):
                    return os.system("sort -m")
                if(Argument.hasOption(["-h"])):
                    return os.system("sort -h")
                if(Argument.hasOption(["-n"])):
                    return os.system("sort -n")
        elif(len(sys.argv)>1):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.sort(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.sort()
        else:
            return Command_help.sort(sys.argv[1])

    def tac(self):
        if(Argument.hasCommands(['tac'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.tac(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.tac()
            return os.system("tac")
    def exit(self):
        if(Argument.hasCommands(['exit'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.exit(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.exit()
            return exit()

    def diff(self):
        if((len(sys.argv)>3) or (len(sys.argv)>4)):
            if(Argument.hasCommands(['diff'])):
                if(Argument.hasOption(["-f"])):
                    return os.system(f"diff -F {sys.argv[2]} {sys.argv[3]}")
                return os.system(f"diff {sys.argv[2]} {sys.argv[3]}")
        elif(len(sys.argv)>2):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.diff(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.diff()
        else:
            return Command_help.diff(sys.argv[1])

    def dmidecode(self):
        if(len(sys.argv)>3):
            if(Argument.hasCommands(['dmidecode'])):
                if(Argument.hasOption(['-d']) or Argument.hasCommands(['dev-mem'])):
                    return os.system(f"dmidecode -d {sys.argv[3]}")
                if(Argument.hasOption(['-q']) or Argument.hasCommands(['quiet'])):
                    return os.system("dmidecode -q")
                if(Argument.hasOption(['-s']) or Argument.hasCommands(['string'])):
                    return os.system(f"dmidecode -s {sys.argv[3]}")
                if(Argument.hasOption(['-t']) or Argument.hasCommands(['type'])):
                    return os.system(f"dmidecode -t {sys.argv[3]}")
                if(Argument.hasOption(['-H']) or Argument.hasCommands(['handle'])):
                    return os.system(f"dmidecode -H {sys.argv[3]}")
                if(Argument.hasOption(['-u']) or Argument.hasCommands(['dump'])):
                    return os.system(f"dmidecode -u {sys.argv[3]}")
                if(Argument.hasCommands(['dump-bin'])):
                    return os.system(f"dmidecode --dump-bin {sys.argv[3]}")
                if(Argument.hasCommands(['from-dump'])):
                    return os.system(f"dmidecode --from-dump {sys.argv[3]}")
                if(Argument.hasCommands(['no-sysfs'])):
                    return os.system(f"dmidecode --no-sysfs {sys.argv[3]}")
                elif(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.dmidecode(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.dmidecode()
                
        else:
            return Command_help.dmidecode(sys.argv[1])

    def netstat(self):
        if(Argument.hasCommands(['netstat'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.netstat(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.netstat()
            return os.system("netstat")
    def mpstat(self):
        if(Argument.hasCommands(['mpstat'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.mpstat(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.mpstat()
            return os.system("mpstat")
    def wc(self):
        if(Argument.hasCommands(['wc'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.wc(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.wc()
            print("The count of files :: ")
            return os.system("ls | wc -l")
    def nproc(self):
        if(Argument.hasCommands(['nproc'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.nproc(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.nproc()
            return os.system("nproc")
    def sleep(self):
        if(Argument.hasCommands(['sleep'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.sleep(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.sleep()
            
            return time.sleep(int(sys.argv[2]))
    def lsblk(self):
        if(Argument.hasCommands(['lsblk'])):
            if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                return Command_help.lsblk(sys.argv[1])
            if(Argument.hasCommands(["show"])):
                return Show_details.lsblk()
            
            return os.system('lsblk')
    def Which_type(self):
        if(len(sys.argv)>2):
            if(Argument.hasCommands(['Which_type'])):
                if(Argument.hasOption(['-h']) or Argument.hasOption(['--help'])):
                    return Command_help.Which_type(sys.argv[1])
                if(Argument.hasCommands(["show"])):
                    return Show_details.Which_type()
            return Where_locate.find_location()
        else:
            return Command_help.Which_type(sys.argv[1])
    
            


    
                
                         
    
            

               
                


from setuptools import setup, find_packages
import os


requirements = os.popen("/usr/local/bin/pipreqs main --print").read().splitlines()
with open('README.md', 'r', encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name='linuxmedia_sridhar',
    version='0.1.1',
    author='Sridhar',
    author_email='dcsvsridhar@gmail.com',
    description='Linuxmedia is a wrapper for 60 above 60+ Linux Commands',
    packages=find_packages(),
    url='https://git.selfmade.ninja/SRIDHARDSCV/packaging_own_cli_tool',
    install_requires=requirements,
    # install_requires=[],
    long_description=long_description,
    long_description_content_type='text/markdown',
    entry_points={
        'console_scripts': [
            'linuxmedia=main.main:main',
        ],
    },
)